/* PIO-D96 Linux Static Libary.

   Author: Golden Wang

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software Foundation,
   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */

/* File level history (record changes for this file here.)

   Use vi or gvim to edit this file and set tabstop=4.

   v 0.0.0  7  Sep 2007 by Golden Wang
     function created for digital I/O and signal interrupt.

*/

#include "piodio.h"

extern char device_module[LINE_SIZE + 1];
extern dev_control_t *dev_ctl;

void piod96_port_config(unsigned int *reg_value, WORD port, boolean io)
{
  if ( ((short)port == 0 && io == 0) || (port == 3 && io == 0) ||
       (port == 6 && io == 0) || (port == 9 && io == 0) )
  {
    *reg_value = *reg_value | 0x01;
  }
  else if ( ((short)port == 0 && io == 1) || (port == 3 && io == 1) ||
            (port == 6 && io == 1) || (port == 9 && io == 1))
  {
    *reg_value = *reg_value & 0x06;
  }

  if ( (port == 1 && io == 0) || (port == 4 && io == 0) ||
       (port == 7 && io == 0) || (port == 10 && io == 0) )
  {
    *reg_value = *reg_value | 0x02;
  }
  else if ( (port == 1 && io == 1) || (port == 4 && io == 1) ||
            (port == 7 && io == 1) || (port == 10 && io == 1))
  {
    *reg_value = *reg_value & 0x05;
  }

  if ( (port == 2 && io == 0) || (port == 5 && io == 0) ||
       (port == 8 && io == 0) || (port == 11 && io == 0) )
  {
    *reg_value = *reg_value | 0x04;
  }
  else if ( (port == 2 && io == 1) || (port == 5 && io == 1) ||
            (port == 8 && io == 1) || (port == 11 && io == 1))
  {
    *reg_value = *reg_value & 0x03;
  }

}

  

WORD PIOD96_PortDirCfs(WORD fd, WORD port, boolean io)
{
  ixpio_reg_t reg;

  if ( (short)port >= 0 && port < 3 )
  {
    reg.id = IXPIO_PCA;
    reg.value = (dev_ctl->pconf[LEVEL_A].init) ? dev_ctl->pconf[LEVEL_A].status : 0;
    piod96_port_config(&reg.value, port, io);
    if (PIODA_OutputByte(fd, &reg)) return FAILURE;

    dev_ctl->pconf[LEVEL_A].status = reg.value;
    dev_ctl->pconf[LEVEL_A].id = reg.id;
    if ( !dev_ctl->pconf[LEVEL_A].init ) dev_ctl->pconf[LEVEL_A].init = 1;
  }
  else if ( port >= 3 && port < 6 )
  {
    reg.id = IXPIO_PCB;
    reg.value = (dev_ctl->pconf[LEVEL_B].init) ? dev_ctl->pconf[LEVEL_B].status : 0;
    piod96_port_config(&reg.value, port, io);
    if (PIODA_OutputByte(fd, &reg)) return FAILURE;

    dev_ctl->pconf[LEVEL_B].status = reg.value;
    dev_ctl->pconf[LEVEL_B].id = reg.id;
    if ( !dev_ctl->pconf[LEVEL_B].init ) dev_ctl->pconf[LEVEL_B].init = 1; 
  }
  else if ( port >= 6 && port < 9 )
  {
    reg.id = IXPIO_PCC;
    reg.value = (dev_ctl->pconf[LEVEL_C].init) ? dev_ctl->pconf[LEVEL_C].status : 0;

    piod96_port_config(&reg.value, port, io);
    if (PIODA_OutputByte(fd, &reg)) return FAILURE;

    dev_ctl->pconf[LEVEL_C].status = reg.value;
    dev_ctl->pconf[LEVEL_C].id = reg.id;
    if ( !dev_ctl->pconf[LEVEL_C].init ) dev_ctl->pconf[LEVEL_C].init = 1;
  }
  else if ( port >= 9 && port < 12 )
  {
    reg.id = IXPIO_PCD;
    reg.value = (dev_ctl->pconf[LEVEL_D].init) ? dev_ctl->pconf[LEVEL_D].status : 0;

    piod96_port_config(&reg.value, port, io);
    if (PIODA_OutputByte(fd, &reg)) return FAILURE;

    dev_ctl->pconf[LEVEL_D].status = reg.value;
    dev_ctl->pconf[LEVEL_D].id = reg.id;
    if ( !dev_ctl->pconf[LEVEL_D].init ) dev_ctl->pconf[LEVEL_D].init = 1;
  }

  return SUCCESS;
}

WORD PIOD96_Digital_Output(WORD fd, WORD port, byte data)
{
  ixpio_reg_t reg;

  WORD PIOD96_PORT_ID[12] = {
				 IXPIO_P0, IXPIO_P1, IXPIO_P2,
				 IXPIO_P3, IXPIO_P4, IXPIO_P5,
				 IXPIO_P6, IXPIO_P7, IXPIO_P8,
				 IXPIO_P9, IXPIO_P10, IXPIO_P11
			    };

  reg.id = PIOD96_PORT_ID[port];
  reg.value = data;

  /* setup I/O Selection Control Register */
  if (PIODA_OutputByte(fd, &reg)) return PIODA_DIGITAL_OUTPUT_ERROR;

  return SUCCESS;
}

WORD PIOD96_Digital_Input(WORD fd, WORD port, WORD *di_data)
{
  ixpio_reg_t reg;

  WORD PIOD96_PORT_ID[12] = {
                                 IXPIO_P0, IXPIO_P1, IXPIO_P2,
                                 IXPIO_P3, IXPIO_P4, IXPIO_P5,
                                 IXPIO_P6, IXPIO_P7, IXPIO_P8,
                                 IXPIO_P9, IXPIO_P10, IXPIO_P11
                            };

  reg.id = PIOD96_PORT_ID[port];

  if (PIODA_InputByte(fd, &reg)) return PIODA_DIGITAL_INPUT_ERROR;

  *di_data = reg.value;

  return SUCCESS;
}

WORD PIOD96_Int_Source_Init(WORD fd, WORD signal, WORD int_source)
{
  ixpio_reg_t reg;
  struct sigaction act_old;
  WORD rs;

  if ( !strcmp(device_module,"ixpiod96") )
  {
    if ( int_source == PIOD96_P2C0 )
    {
      rs = PIODA_PortDirCfs(fd, 2, DIGITAL_INPUT);
    }
    else if ( int_source == PIOD96_P5C0 )
    {
      rs = PIODA_PortDirCfs(fd, 5, DIGITAL_INPUT);
    }
    else if ( int_source == PIOD96_P8C0 )
    {
      rs = PIODA_PortDirCfs(fd, 8, DIGITAL_INPUT);
    }
    else if ( int_source == PIOD96_P11C0 )
    {
      rs = PIODA_PortDirCfs(fd, 11, DIGITAL_INPUT);
    }
    else if ( int_source == PIOD96_ALL_INT )
    {
      rs = PIODA_PortDirCfs(fd, 2, DIGITAL_INPUT);
      rs = PIODA_PortDirCfs(fd, 5, DIGITAL_INPUT);
      rs = PIODA_PortDirCfs(fd, 8, DIGITAL_INPUT);
      rs = PIODA_PortDirCfs(fd, 11, DIGITAL_INPUT);
    }
    else
    {
      close(fd);
      sigaction(signal, &act_old, NULL);
      return PIODA_INT_SOURCE_DEFINED_ERROR;
    }
  }

  if ( rs )
  {
    sigaction(signal, &act_old, NULL);
    return PIODA_ACTIVE_PORT_ERROR;
  }

  /* configure board interrupt */
  reg.id = IXPIO_IMCR;
  reg.value = int_source;

  if (PIODA_OutputByte(fd, &reg))
  {
    sigaction(signal, &act_old, NULL);
    return PIODA_CONFIGURE_INTERRUPT_ERROR;
  }

  return SUCCESS;
}

